@@ -3,10 +3,12 @@ import asyncio
 import logging
 import pprint
 import random
-from typing import Awaitable, Callable, List
+import uuid
+from typing import Awaitable, Callable, List, Optional
 
 from aiohttp import ClientSession, WSMsgType, client_exceptions
 
+from .event import Event
 from .model.driver import Driver
 
 STATE_CONNECTING = "connecting"
@@ -17,6 +19,7 @@ STATE_DISCONNECTED = "disconnected"
 async def gather_callbacks(
     logger: logging.Logger, name: str, callbacks: List[Callable[[], Awaitable[None]]]
 ) -> None:
+    """Gather callbacks."""
     results = await asyncio.gather(*[cb() for cb in callbacks], return_exceptions=True)
     for result, callback in zip(results, callbacks):
         if not isinstance(result, Exception):
@@ -32,6 +35,16 @@ class InvalidState(Exception):
     """Exception raised when data gets in invalid state."""
 
 
+class FailedCommand(Exception):
+    """When a command has failed."""
+
+    def __init__(self, message_id: str, error_code: str):
+        """Initialize a failed command error."""
+        super().__init__(f"Command failed: {error_code}")
+        self.message_id = message_id
+        self.error_code = error_code
+
+
 class Client:
     """Class to manage the IoT connection."""
 
@@ -39,7 +52,7 @@ class Client:
         """Initialize the Client class."""
         self.ws_server_url = ws_server_url
         self.aiohttp_session = aiohttp_session
-        self.driver = None
+        self.driver: Optional[Driver] = None
         # The WebSocket client
         self.client = None
         # Scheduled sleep task till next connection retry
@@ -58,11 +71,13 @@ class Client:
 
     def async_handle_message(self, msg) -> None:
         """Handle incoming message.
+
         Run all async tasks in a wrapper to log appropriately.
         """
-        if msg["type"] == "state":
+        # Right now only result is from receiving state.
+        if msg["type"] == "result":
             if self.driver is None:
-                self.driver = Driver(msg["state"])
+                self.driver = Driver(msg["result"]["state"])
                 self._logger.info(
                     "Z-Wave JS initialized. %s nodes", len(self.driver.controller.nodes)
                 )
@@ -84,7 +99,8 @@ class Client:
             # Can't handle
             return
 
-        self.driver.receive_event(msg["event"])
+        event = Event(type=msg["event"]["event"], data=msg["event"])
+        self.driver.receive_event(event)
 
     def register_on_connect(self, on_connect_cb: Callable[[], Awaitable[None]]):
         """Register an async on_connect callback."""
@@ -165,7 +181,9 @@ class Client:
         await self.retry_task
         self.retry_task = None
 
-    async def _handle_connection(self):
+    async def _handle_connection(
+        self,
+    ):  # pylint: disable=too-many-branches, too-many-statements
         """Connect to the Z-Wave JS server."""
         client = None
         disconnect_warn = None
@@ -176,12 +194,23 @@ class Client:
             )
             self.tries = 0
 
-            self._logger.info("Connected")
+            version_msg = await client.receive_json()
+
+            self._logger.info(
+                "Connected to Home %s (Server %s, Driver %s)",
+                version_msg["homeId"],
+                version_msg["serverVersion"],
+                version_msg["driverVersion"],
+            )
             self.state = STATE_CONNECTED
 
             if self._on_connect:
                 await gather_callbacks(self._logger, "on_connect", self._on_connect)
 
+            await client.send_json(
+                {"messageId": uuid.uuid4().hex, "command": "start_listening"}
+            )
+
             while not client.closed:
                 msg = await client.receive()
 
